==> nextcloud-app-calendar-1%3A5.5.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/sq.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s ka publikuar kalendarin %s",
    "Hello," : "Përshëndetje,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Donim t'ju informonim se %s ka publikuar kalendarin »%s«",
    "Open »%s«" : "Hap »%s«",
    "Cheers!" : "Gëzuar!",
    "Calendar" : "Kalendar",
    "Appointments" : "Takime",
    "Confirm" : "Konfirmo",
    "Description:" : "Përshkrimi:",
    "Where:" : "Ku:",
    "Location:" : "Vendndodhje:",
    "Today" : "Sot",
    "Day" : "Ditë",
    "Week" : "Javë",
    "Month" : "Muaj",
    "List" : "List",
    "Preview" : "Parapamje ",
    "Copy link" : "Kopjo linkun",
    "Edit" : "Përpuno",
    "Delete" : "Fshije",
    "Create new" : "Krijo të ri",
    "New calendar" : "Kalendar i ri",
    "Export" : "Eksport",
    "Name" : "Emri",
    "Deleted" : "E fshirë",
    "Restore" : "Rikthe",
    "Delete permanently" : "Fshije përgjithmonë",
    "Deck" : "Shto paisjen U2F",
    "Hidden" : "I fshehur",
    "Copy internal link" : "Kopjoni lidhjen e brendshme",
    "Share link" : "Ndani lidhjen",
    "can edit" : "mund të përpunojnë",
    "Share with users or groups" : "Nda me përdoruesit ose grupet",
    "Save" : "Ruaj",
    "View" : "Shiko",
    "Filename" : "Emri i skedarit",
    "Cancel" : "Anuloje",
    "Automatic" : "Automatike",
    "List view" : "Pamje listë",
    "Actions" : "Veprimet",
    "Show week numbers" : "Shfaq numra javësh",
    "Update" : "Përditësoje",
    "Location" : "Vendndodhje",
    "Description" : "Përshkrim",
    "Duration" : "Kohëzgjatja",
    "to" : "te",
    "Add" : "Shto",
    "Monday" : "E hënë",
    "Tuesday" : "E martë",
    "Wednesday" : "E mërkurë",
    "Thursday" : "E enjte",
    "Friday" : "E premte",
    "Saturday" : "E shtunë",
    "Sunday" : "E dielë",
    "Your email address" : "Adresa juaj email",
    "Back" : "Mbrapsht",
    "Notification" : "Njoftim",
    "Email" : "Emaili",
    "seconds" : "sekonda",
    "minutes" : "minuta",
    "hours" : "orë",
    "days" : "ditë",
    "weeks" : "javë",
    "Choose a file to add as attachment" : "Zgjidhni një kartelë që të shtohet si bashkëngjitje",
    "Delete file" : "Fshi skedarin",
    "Available" : "i disponueshëm",
    "Done" : "U bë",
    "Room name" : "Emri i dhomës",
    "Unknown" : "I/E panjohur",
    "Accept" : "Prano",
    "Decline" : "Refuzo",
    "Tentative" : "Tentativë",
    "Attendees" : "Pjesëmarrës",
    "Remove group" : "Hiq grupin",
    "Repeat" : "Përsërite",
    "never" : "kurrë",
    "after" : "pas",
    "Resources" : "Burimet",
    "available" : "në gjëndje",
    "Yes" : "Po",
    "Create" : "Krijo",
    "Global" : "Globale",
    "Subscribe" : "Abonohu",
    "Personal" : "Personale",
    "Edit event" : "Përpunoni veprimtarinë",
    "All day" : "Gjithë ditën",
    "Close" : "Mbylle",
    "Title" : "Titulli",
    "Anniversary" : "Përvjetor",
    "Week {number} of {year}" : "Java e {number} e {year}",
    "Daily" : "Përditë",
    "Weekly" : "Çdo javë",
    "second" : "sekondë",
    "Other" : "Tjetër",
    "When shared show full event" : "Kur ndahet shfaqje e veprimtarisë së plotë",
    "When shared show only busy" : "Kur ndahet shfaqje vetëm i zënë",
    "When shared hide this event" : "Kur ndahet fshihe këtë veprimtari",
    "Status" : "Status",
    "Confirmed" : "E konfirmuar",
    "Canceled" : "Anuluar",
    "Categories" : "Kategoritë"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1%3A5.5.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/sq.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s ka publikuar kalendarin %s",
    "Hello," : "Përshëndetje,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Donim t'ju informonim se %s ka publikuar kalendarin »%s«",
    "Open »%s«" : "Hap »%s«",
    "Cheers!" : "Gëzuar!",
    "Calendar" : "Kalendar",
    "Appointments" : "Takime",
    "Confirm" : "Konfirmo",
    "Description:" : "Përshkrimi:",
    "Where:" : "Ku:",
    "Location:" : "Vendndodhje:",
    "Today" : "Sot",
    "Day" : "Ditë",
    "Week" : "Javë",
    "Month" : "Muaj",
    "List" : "List",
    "Preview" : "Parapamje ",
    "Copy link" : "Kopjo linkun",
    "Edit" : "Përpuno",
    "Delete" : "Fshije",
    "Create new" : "Krijo të ri",
    "New calendar" : "Kalendar i ri",
    "Export" : "Eksport",
    "Name" : "Emri",
    "Deleted" : "E fshirë",
    "Restore" : "Rikthe",
    "Delete permanently" : "Fshije përgjithmonë",
    "Deck" : "Shto paisjen U2F",
    "Copy internal link" : "Kopjoni lidhjen e brendshme",
    "Share link" : "Ndani lidhjen",
    "can edit" : "mund të përpunojnë",
    "Share with users or groups" : "Nda me përdoruesit ose grupet",
    "Save" : "Ruaj",
    "View" : "Shiko",
    "Filename" : "Emri i skedarit",
    "Cancel" : "Anuloje",
    "Automatic" : "Automatike",
    "Automatic ({timezone})" : "Automatike ({zona kohore})",
    "List view" : "Pamje listë",
    "Actions" : "Veprimet",
    "General" : "Të përgjithshme",
    "Show week numbers" : "Shfaq numra javësh",
    "Keyboard shortcuts" : "Shkurtoret e tastierës",
    "Update" : "Përditësoje",
    "Location" : "Vendndodhje",
    "Description" : "Përshkrim",
    "Duration" : "Kohëzgjatja",
    "to" : "te",
    "Add" : "Shto",
    "Monday" : "E hënë",
    "Tuesday" : "E martë",
    "Wednesday" : "E mërkurë",
    "Thursday" : "E enjte",
    "Friday" : "E premte",
    "Saturday" : "E shtunë",
    "Sunday" : "E dielë",
    "Your email address" : "Adresa juaj email",
    "Back" : "Mbrapsht",
    "Notification" : "Njoftim",
    "Email" : "Emaili",
    "seconds" : "sekonda",
    "minutes" : "minuta",
    "hours" : "orë",
    "days" : "ditë",
    "weeks" : "javë",
    "Choose a file to add as attachment" : "Zgjidhni një kartelë që të shtohet si bashkëngjitje",
    "Delete file" : "Fshi skedarin",
    "Available" : "i disponueshëm",
    "Done" : "U bë",
    "Room name" : "Emri i dhomës",
    "Unknown" : "I/E panjohur",
    "Accept" : "Prano",
    "Decline" : "Refuzo",
    "Tentative" : "Tentativë",
    "Attendees" : "Pjesëmarrës",
    "Remove group" : "Hiq grupin",
    "Repeat" : "Përsërite",
    "never" : "kurrë",
    "after" : "pas",
    "Resources" : "Burimet",
    "available" : "në gjëndje",
    "Yes" : "Po",
    "None" : "Asnjë",
    "Create" : "Krijo",
    "Global" : "Globale",
    "Subscribe" : "Abonohu",
    "Personal" : "Personale",
    "Edit event" : "Përpunoni veprimtarinë",
    "All day" : "Gjithë ditën",
    "Close" : "Mbylle",
    "Title" : "Titulli",
    "Submit" : "Dërgo",
    "Anniversary" : "Përvjetor",
    "Week {number} of {year}" : "Java e {number} e {year}",
    "Daily" : "Përditë",
    "Weekly" : "Çdo javë",
    "second" : "sekondë",
    "Other" : "Tjetër",
    "When shared show full event" : "Kur ndahet shfaqje e veprimtarisë së plotë",
    "When shared show only busy" : "Kur ndahet shfaqje vetëm i zënë",
    "When shared hide this event" : "Kur ndahet fshihe këtë veprimtari",
    "Status" : "Status",
    "Confirmed" : "E konfirmuar",
    "Canceled" : "Anuluar",
    "Categories" : "Kategoritë",
    "Hidden" : "I fshehur"
},
"nplurals=2; plural=(n != 1);");
